@@ -60,8 +60,8 @@ gt_load_png_as_traffic_raster <- function(filename,
     ## Image to hex
     rimg <- raster::as.raster(img) 
 
-    google_colours = c("#63D668", "#FF974D", "#F23C32", "#811F1F")
-    #google_colours = c("#11D68F", "#FFCF43", "#F24E42", "#A92727")
+    #google_colours = c("#63D668", "#FF974D", "#F23C32", "#811F1F")
+    google_colours = c("#11D68F", "#FFCF43", "#F24E42", "#A92727")
     google_colours_ff <- paste0(google_colours, "FF")
     
     if(traffic_color_dist_thresh == 0){
